@@ -1,12 +1,13 @@
 {-# LANGUAGE CPP #-}
-{-# LANGUAGE OverloadedStrings #-}
 {-# LANGUAGE ImplicitParams #-}
+{-# LANGUAGE OverloadedStrings #-}
+{-# LANGUAGE QuasiQuotes #-}
 
 module Main where
 
-import Control.Exception.Safe
 import Control.Monad
 import Control.Monad.IO.Class
+import Data.String.Interpolate
 import FSNotify.Test.EventTests
 import FSNotify.Test.Util
 import Prelude hiding (FilePath)
@@ -17,10 +18,13 @@ import UnliftIO.IORef
 
 
 main :: IO ()
-main = runSandwichWithCommandLineArgs defaultOptions $ parallelN 20 $ do
+main =
+  withTestFolderGenerator $ \testFolderGenerator ->
+  runSandwichWithCommandLineArgs defaultOptions $ parallelN 20 $ do
     describe "Configuration" $ do
       it "respects the confOnHandlerException option" $ do
-        withRandomTempDirectory $ \watchedDir' -> do
+        withRandomTempDirectory testFolderGenerator $ \watchedDir' -> do
+          info [i|Got temp dir: #{watchedDir'}|]
           exceptions <- newIORef (0 :: Int)
           let conf = defaultConfig { confOnHandlerException = \_ -> modifyIORef exceptions (+ 1) }
 
@@ -28,20 +32,19 @@ main = runSandwichWithCommandLineArgs defaultOptions $ parallelN 20 $ do
             stop <- watchDir mgr watchedDir' (const True) $ \ev -> do
               case ev of
 #ifdef darwin_HOST_OS
-                Modified {} -> throwIO $ userError "Oh no!"
+                Modified {} -> expectationFailure "Oh no!"
 #else
-                Added {} -> throwIO $ userError "Oh no!"
+                Added {} -> expectationFailure "Oh no!"
 #endif
                 _ -> return ()
 
             writeFile (watchedDir' </> "testfile") "foo"
 
-            let ?timeInterval = 5*10^(5 :: Int)
-            pauseAndRetryOnExpectationFailure 3 $
+            waitUntil 5.0 $
               readIORef exceptions >>= (`shouldBe` 1)
 
             stop
 
-    describe "SingleThread" $ eventTests SingleThread
-    describe "ThreadPerWatch" $ eventTests ThreadPerWatch
-    describe "ThreadPerEvent" $ eventTests ThreadPerEvent
+    describe "SingleThread" $ eventTests testFolderGenerator SingleThread
+    describe "ThreadPerWatch" $ eventTests testFolderGenerator ThreadPerWatch
+    describe "ThreadPerEvent" $ eventTests testFolderGenerator ThreadPerEvent
